Index: content/public/browser/resource_throttle_controller.h |
diff --git a/content/public/browser/resource_throttle_controller.h b/content/public/browser/resource_throttle_controller.h |
index d7e87c7727cee6360bf66a822a8d5d3bf349b4a8..a9499b6e160e4169f9f2b9b922dc424ba074c9ed 100644 |
--- a/content/public/browser/resource_throttle_controller.h |
+++ b/content/public/browser/resource_throttle_controller.h |
@@ -8,10 +8,12 @@ |
namespace content { |
// Used by ResourceThrottle implementations to either resume a deferred |
// resource load or cancel a resource load at any time. |
class ResourceThrottleController { |
public: |
virtual void Cancel() = 0; |
+ virtual void CancelWithHandledExternallyStatus() = 0; |
virtual void Resume() = 0; |
protected: |
virtual ~ResourceThrottleController() {} |
@@ -8,10 +8,12 @@ |
namespace content { |
// Used by ResourceThrottle implementations to either resume a deferred |
-// resource load or cancel a resource load at any time. |
+// resource load, cancel a resource load or indicate that the resource load has |
+// been handled externally at any time. |
class ResourceThrottleController { |
public: |